MollieAPI.Api.BalanceTransfersAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged BalanceTransfersAPI.
Summary
Functions
Create a Connect balance transfer
This API endpoint allows you to create a balance transfer from your organization's balance to a connected organization's balance, or vice versa. You can also create a balance transfer between two connected organizations. To create a balance transfer, you must be authenticated as the source organization, and the destination organization must be a connected organization that has authorized the balance-transfers.write scope for your organization.
Get a Connect balance transfer Retrieve a single Connect balance transfer object by its ID.
List all Connect balance transfers Returns a paginated list of balance transfers associated with your organization. These may be a balance transfer that was received or sent from your balance, or a balance transfer that you initiated on behalf of your clients. If no balance transfers are available, the resulting array will be empty. This request should never throw an error.
Functions
@spec create_connect_balance_transfer( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.EntityBalanceTransferResponse.t()} | {:error, Tesla.Env.t()}
Create a Connect balance transfer
This API endpoint allows you to create a balance transfer from your organization's balance to a connected organization's balance, or vice versa. You can also create a balance transfer between two connected organizations. To create a balance transfer, you must be authenticated as the source organization, and the destination organization must be a connected organization that has authorized the balance-transfers.write scope for your organization.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(EntityBalanceTransfer):
Returns
{:ok, MollieAPI.Model.EntityBalanceTransferResponse.t}on success{:error, Tesla.Env.t}on failure
@spec get_connect_balance_transfer(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.EntityBalanceTransferResponse.t()} | {:error, Tesla.Env.t()}
Get a Connect balance transfer Retrieve a single Connect balance transfer object by its ID.
Parameters
connection(MollieAPI.Connection): Connection to serverbalance_transfer_id(String.t): Provide the ID of the related balance transfer.opts(keyword): Optional parameters:testmode(boolean()): You can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityBalanceTransferResponse.t}on success{:error, Tesla.Env.t}on failure
@spec list_connect_balance_transfers( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ListConnectBalanceTransfers200Response.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
List all Connect balance transfers Returns a paginated list of balance transfers associated with your organization. These may be a balance transfer that was received or sent from your balance, or a balance transfer that you initiated on behalf of your clients. If no balance transfers are available, the resulting array will be empty. This request should never throw an error.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:testmode(boolean()): You can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListConnectBalanceTransfers200Response.t}on success{:error, Tesla.Env.t}on failure