MollieAPI.Api.ChargebacksAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged ChargebacksAPI.
Summary
Functions
Get payment chargeback Retrieve a single payment chargeback by its ID and the ID of its parent payment.
List all chargebacks Retrieve all chargebacks initiated for all your payments. The results are paginated.
List payment chargebacks Retrieve the chargebacks initiated for a specific payment. The results are paginated.
Functions
@spec get_chargeback(Tesla.Env.client(), String.t(), String.t(), keyword()) :: {:ok, MollieAPI.Model.EntityChargeback.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Get payment chargeback Retrieve a single payment chargeback by its ID and the ID of its parent payment.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.chargeback_id(String.t): Provide the ID of the related chargeback.opts(keyword): Optional parameters:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityChargeback.t}on success{:error, Tesla.Env.t}on failure
@spec list_all_chargebacks( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ListSettlementChargebacks200Response.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
List all chargebacks Retrieve all chargebacks initiated for all your payments. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:profileId(String.t): The identifier referring to the profile you wish to retrieve chargebacks for. Most API credentials are linked to a single profile. In these cases theprofileIdis already implied. To retrieve all chargebacks across the organization, use an organization-level API credential and omit theprofileIdparameter.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListSettlementChargebacks200Response.t}on success{:error, Tesla.Env.t}on failure
@spec list_chargebacks(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ListSettlementChargebacks200Response.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
List payment chargebacks Retrieve the chargebacks initiated for a specific payment. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.opts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListSettlementChargebacks200Response.t}on success{:error, Tesla.Env.t}on failure