MollieAPI.Api.ClientsAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged ClientsAPI.

Summary

Functions

Get client Retrieve a single client by its ID.

List clients Retrieve a list of all clients linked to your account. The results are paginated.

Functions

get_client(connection, organization_id, opts \\ [])

Get client Retrieve a single client by its ID.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • organization_id (String.t): Provide the ID of the related organization.
  • opts (keyword): Optional parameters
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.GetClient200Response.t} on success
  • {:error, Tesla.Env.t} on failure

list_clients(connection, opts \\ [])

@spec list_clients(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.ListClients200Response.t()}
  | {:error, Tesla.Env.t()}

List clients Retrieve a list of all clients linked to your account. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListClients200Response.t} on success
  • {:error, Tesla.Env.t} on failure