MollieAPI.Api.DelayedRoutingAPI (mollie_api v0.1.0-20260130)

API calls for all endpoints tagged DelayedRoutingAPI.

Summary

Functions

Create a delayed route Create a route for a specific payment. The routed amount is credited to the account of your customer.

List payment routes Retrieve a list of all routes created for a specific payment.

Functions

payment_create_route(connection, payment_id, opts \\ [])

@spec payment_create_route(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.RouteCreateResponse.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Create a delayed route Create a route for a specific payment. The routed amount is credited to the account of your customer.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (EntityRoute):

Returns

  • {:ok, MollieAPI.Model.RouteCreateResponse.t} on success
  • {:error, Tesla.Env.t} on failure

payment_list_routes(connection, payment_id, opts \\ [])

List payment routes Retrieve a list of all routes created for a specific payment.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter can be omitted. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.PaymentListRoutes200Response.t} on success
  • {:error, Tesla.Env.t} on failure