MollieAPI.Api.InvoicesAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged InvoicesAPI.

Summary

Functions

Get invoice Retrieve a single invoice by its ID. If you want to retrieve the details of an invoice by its invoice number, call the List invoices endpoint with the reference parameter.

List invoices Retrieve a list of all your invoices, optionally filtered by year or by invoice reference. The results are paginated.

Functions

get_invoice(connection, invoice_id, opts \\ [])

@spec get_invoice(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.EntityInvoice.t()}
  | {:error, Tesla.Env.t()}

Get invoice Retrieve a single invoice by its ID. If you want to retrieve the details of an invoice by its invoice number, call the List invoices endpoint with the reference parameter.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • invoice_id (String.t): Provide the ID of the related invoice.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityInvoice.t} on success
  • {:error, Tesla.Env.t} on failure

list_invoices(connection, opts \\ [])

@spec list_invoices(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.ListInvoices200Response.t()}
  | {:error, Tesla.Env.t()}

List invoices Retrieve a list of all your invoices, optionally filtered by year or by invoice reference. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :reference (String.t): Filter for an invoice with a specific invoice reference, for example 2024.10000.
    • :year (String.t): Filter for invoices of a specific year, for example 2024.
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :sort (Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListInvoices200Response.t} on success
  • {:error, Tesla.Env.t} on failure