MollieAPI.Api.OnboardingAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged OnboardingAPI.
Summary
Functions
Get onboarding status Retrieve the onboarding status of the currently authenticated organization.
Submit onboarding data
⚠️ We no longer recommend implementing this endpoint. Please refer to the Client Links API instead to kick off the onboarding process for your merchants. Submit data that will be prefilled in the merchant's onboarding. The data you submit will only be processed when the onboarding status is needs-data. Information that the merchant has entered in their dashboard will not be overwritten.
Functions
@spec get_onboarding_status( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.EntityOnboardingStatus.t()} | {:error, Tesla.Env.t()}
Get onboarding status Retrieve the onboarding status of the currently authenticated organization.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityOnboardingStatus.t}on success{:error, Tesla.Env.t}on failure
@spec submit_onboarding_data( Tesla.Env.client(), keyword() ) :: {:ok, nil} | {:error, Tesla.Env.t()}
Submit onboarding data
⚠️ We no longer recommend implementing this endpoint. Please refer to the Client Links API instead to kick off the onboarding process for your merchants. Submit data that will be prefilled in the merchant's onboarding. The data you submit will only be processed when the onboarding status is needs-data. Information that the merchant has entered in their dashboard will not be overwritten.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(SubmitOnboardingDataRequest):
Returns
{:ok, nil}on success{:error, Tesla.Env.t}on failure