MollieAPI.Api.OrganizationsAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged OrganizationsAPI.

Summary

Functions

Get current organization Retrieve the currently authenticated organization. A convenient alias of the Get organization endpoint. For a complete reference of the organization object, refer to the Get organization endpoint documentation.

Get organization Retrieve a single organization by its ID. You can normally only retrieve the currently authenticated organization with this endpoint. This is primarily useful for OAuth apps. See also Get current organization. If you have a partner account', you can retrieve organization details of connected organizations.

Get partner status Retrieve partnership details about the currently authenticated organization. Only relevant for so-called partner accounts.

Functions

get_current_organization(connection, opts \\ [])

@spec get_current_organization(
  Tesla.Env.client(),
  keyword()
) :: {:ok, MollieAPI.Model.EntityOrganization.t()} | {:error, Tesla.Env.t()}

Get current organization Retrieve the currently authenticated organization. A convenient alias of the Get organization endpoint. For a complete reference of the organization object, refer to the Get organization endpoint documentation.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityOrganization.t} on success
  • {:error, Tesla.Env.t} on failure

get_organization(connection, organization_id, opts \\ [])

@spec get_organization(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.EntityOrganization.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Get organization Retrieve a single organization by its ID. You can normally only retrieve the currently authenticated organization with this endpoint. This is primarily useful for OAuth apps. See also Get current organization. If you have a partner account', you can retrieve organization details of connected organizations.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • organization_id (String.t): Provide the ID of the related organization.
  • opts (keyword): Optional parameters
    • :testmode (boolean()): You can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityOrganization.t} on success
  • {:error, Tesla.Env.t} on failure

get_partner_status(connection, opts \\ [])

@spec get_partner_status(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.GetPartnerStatus200Response.t()}
  | {:error, Tesla.Env.t()}

Get partner status Retrieve partnership details about the currently authenticated organization. Only relevant for so-called partner accounts.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.GetPartnerStatus200Response.t} on success
  • {:error, Tesla.Env.t} on failure