MollieAPI.Api.PaymentsAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged PaymentsAPI.

Summary

Functions

Cancel payment Depending on the payment method, you may be able to cancel a payment for a certain amount of time — usually until the next business day or as long as the payment status is open. Payments may also be canceled manually from the Mollie Dashboard. The isCancelable property on the Payment object will indicate if the payment can be canceled.

Create payment Payment creation is elemental to the Mollie API: this is where most payment implementations start off. Once you have created a payment, you should redirect your customer to the URL in the _links.checkout property from the response. To wrap your head around the payment process, an explanation and flow charts can be found in the 'Accepting payments' guide. If you specify the method parameter when creating a payment, optional additional parameters may be available for the payment method that are not listed below. Please refer to the guide on method-specific parameters.

Get payment Retrieve a single payment object by its payment ID.

List payments Retrieve all payments created with the current website profile. The results are paginated.

Release payment authorization Releases the full remaining authorized amount. Call this endpoint when you will not be making any additional captures. Payment authorizations may also be released manually from the Mollie Dashboard. Mollie will do its best to process release requests, but it is not guaranteed that it will succeed. It is up to the issuing bank if and when the hold will be released. If the request does succeed, the payment status will change to canceled for payments without captures. If there is a successful capture, the payment will transition to paid.

Update payment Certain details of an existing payment can be updated. Updating the payment details will not result in a webhook call.

Functions

cancel_payment(connection, payment_id, opts \\ [])

@spec cancel_payment(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.PaymentResponse.t()}
  | {:error, Tesla.Env.t()}

Cancel payment Depending on the payment method, you may be able to cancel a payment for a certain amount of time — usually until the next business day or as long as the payment status is open. Payments may also be canceled manually from the Mollie Dashboard. The isCancelable property on the Payment object will indicate if the payment can be canceled.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (CancelPaymentRequest):

Returns

  • {:ok, MollieAPI.Model.PaymentResponse.t} on success
  • {:error, Tesla.Env.t} on failure

create_payment(connection, opts \\ [])

@spec create_payment(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.PaymentResponse.t()}
  | {:error, Tesla.Env.t()}

Create payment Payment creation is elemental to the Mollie API: this is where most payment implementations start off. Once you have created a payment, you should redirect your customer to the URL in the _links.checkout property from the response. To wrap your head around the payment process, an explanation and flow charts can be found in the 'Accepting payments' guide. If you specify the method parameter when creating a payment, optional additional parameters may be available for the payment method that are not listed below. Please refer to the guide on method-specific parameters.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :include (String.t): This endpoint allows you to include additional information via the include query string parameter.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (PaymentRequest):

Returns

  • {:ok, MollieAPI.Model.PaymentResponse.t} on success
  • {:error, Tesla.Env.t} on failure

get_payment(connection, payment_id, opts \\ [])

@spec get_payment(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.PaymentResponse.t()}
  | {:error, Tesla.Env.t()}

Get payment Retrieve a single payment object by its payment ID.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :include (String.t): This endpoint allows you to include additional information via the include query string parameter.
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.PaymentResponse.t} on success
  • {:error, Tesla.Env.t} on failure

list_payments(connection, opts \\ [])

List payments Retrieve all payments created with the current website profile. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :sort (Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.
    • :profileId (String.t): The identifier referring to the profile you wish to retrieve the resources for. Most API credentials are linked to a single profile. In these cases the profileId must not be sent. For organization-level credentials such as OAuth access tokens however, the profileId parameter is required.
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListSettlementPayments200Response.t} on success
  • {:error, Tesla.Env.t} on failure

release_authorization(connection, payment_id, opts \\ [])

@spec release_authorization(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, nil}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Release payment authorization Releases the full remaining authorized amount. Call this endpoint when you will not be making any additional captures. Payment authorizations may also be released manually from the Mollie Dashboard. Mollie will do its best to process release requests, but it is not guaranteed that it will succeed. It is up to the issuing bank if and when the hold will be released. If the request does succeed, the payment status will change to canceled for payments without captures. If there is a successful capture, the payment will transition to paid.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (ReleaseAuthorizationRequest):

Returns

  • {:ok, nil} on success
  • {:error, Tesla.Env.t} on failure

update_payment(connection, payment_id, opts \\ [])

@spec update_payment(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.PaymentResponse.t()}
  | {:error, Tesla.Env.t()}

Update payment Certain details of an existing payment can be updated. Updating the payment details will not result in a webhook call.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (UpdatePaymentRequest):

Returns

  • {:ok, MollieAPI.Model.PaymentResponse.t} on success
  • {:error, Tesla.Env.t} on failure