MollieAPI.Api.PermissionsAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged PermissionsAPI.

Summary

Functions

Get permission Retrieve a single permission by its ID, and see if the permission is granted to the current access token.

List permissions Retrieve a list of all permissions available to the current access token. The results are not paginated.

Functions

get_permission(connection, permission_id, opts \\ [])

@spec get_permission(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.EntityPermission.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Get permission Retrieve a single permission by its ID, and see if the permission is granted to the current access token.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • permission_id (String.t): Provide the ID of the related permission.
  • opts (keyword): Optional parameters
    • :testmode (boolean()): You can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityPermission.t} on success
  • {:error, Tesla.Env.t} on failure

list_permissions(connection, opts \\ [])

@spec list_permissions(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.ListPermissions200Response.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

List permissions Retrieve a list of all permissions available to the current access token. The results are not paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListPermissions200Response.t} on success
  • {:error, Tesla.Env.t} on failure