MollieAPI.Api.RefundsAPI (mollie_api v0.1.0-20260303)

API calls for all endpoints tagged RefundsAPI.

Summary

Functions

Cancel payment refund Refunds will be executed with a delay of two hours. Until that time, refunds may be canceled manually via the Mollie Dashboard, or by using this endpoint. A refund can only be canceled while its status field is either queued or pending. See the Get refund endpoint for more information.

Create payment refund Creates a refund for a specific payment. The refunded amount is credited to your customer usually either via a bank transfer or by refunding the amount to your customer's credit card.

Get payment refund Retrieve a single payment refund by its ID and the ID of its parent payment.

List all refunds Retrieve a list of all of your refunds. The results are paginated.

List payment refunds Retrieve a list of all refunds created for a specific payment. The results are paginated.

Functions

cancel_refund(connection, payment_id, refund_id, opts \\ [])

@spec cancel_refund(Tesla.Env.client(), String.t(), String.t(), keyword()) ::
  {:ok, nil}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Cancel payment refund Refunds will be executed with a delay of two hours. Until that time, refunds may be canceled manually via the Mollie Dashboard, or by using this endpoint. A refund can only be canceled while its status field is either queued or pending. See the Get refund endpoint for more information.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • refund_id (String.t): Provide the ID of the related refund.
  • opts (keyword): Optional parameters
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, nil} on success
  • {:error, Tesla.Env.t} on failure

create_refund(connection, payment_id, opts \\ [])

Create payment refund Creates a refund for a specific payment. The refunded amount is credited to your customer usually either via a bank transfer or by refunding the amount to your customer's credit card.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (RefundRequest):

Returns

  • {:ok, MollieAPI.Model.EntityRefundResponse.t} on success
  • {:error, Tesla.Env.t} on failure

get_refund(connection, payment_id, refund_id, opts \\ [])

Get payment refund Retrieve a single payment refund by its ID and the ID of its parent payment.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • refund_id (String.t): Provide the ID of the related refund.
  • opts (keyword): Optional parameters
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityRefundResponse.t} on success
  • {:error, Tesla.Env.t} on failure

list_all_refunds(connection, opts \\ [])

List all refunds Retrieve a list of all of your refunds. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :sort (Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :profileId (String.t): The identifier referring to the profile you wish to retrieve the resources for. Most API credentials are linked to a single profile. In these cases the profileId must not be sent. For organization-level credentials such as OAuth access tokens however, the profileId parameter is required.
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListSettlementRefunds200Response.t} on success
  • {:error, Tesla.Env.t} on failure

list_refunds(connection, payment_id, opts \\ [])

List payment refunds Retrieve a list of all refunds created for a specific payment. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • payment_id (String.t): Provide the ID of the related payment.
  • opts (keyword): Optional parameters
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :embed (String.t): This endpoint allows embedding related API items by appending the following values via the embed query string parameter.
    • :testmode (boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases the testmode query parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting the testmode query parameter to true. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListSettlementRefunds200Response.t} on success
  • {:error, Tesla.Env.t} on failure