MollieAPI.Api.SessionsAPI (mollie_api v0.1.0-20260428)
View SourceAPI calls for all endpoints tagged SessionsAPI.
Summary
Functions
@spec create_session( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.SessionResponse.t()} | {:error, Tesla.Env.t()}
Create session
🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Create a session to start a checkout process with Mollie Components.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(SessionRequest):
Returns
{:ok, MollieAPI.Model.SessionResponse.t}on success{:error, Tesla.Env.t}on failure
@spec get_session(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.SessionResponse.t()} | {:error, Tesla.Env.t()}
Get session
🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Retrieve a session to view its details and status to inform your customers about the checkout process.
Parameters
connection(MollieAPI.Connection): Connection to serversession_id(String.t): Provide the ID of the related session.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.SessionResponse.t}on success{:error, Tesla.Env.t}on failure