MollieAPI.Api.TransfersAPI (mollie_api v0.1.0-20260428)
View SourceAPI calls for all endpoints tagged TransfersAPI.
Summary
Functions
@spec create_transfer( Tesla.Env.client(), String.t(), String.t(), String.t(), keyword() ) :: {:ok, MollieAPI.Model.TransferResponse.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Create transfer
🚧 Beta feature > > This feature is currently in beta testing, and the final specification may still change. Create a SEPA Credit Transfer from your Mollie Business Account. To initiate a transfer, you must provide the transfer scheme, the amount, the debtor IBAN (your Mollie Business Account IBAN), and the creditor (recipient) details. Each request must include an
Idempotency-Keyheader to prevent duplicate transfers, and must be signed using theX-Client-SignatureandX-Client-Signed-Atheaders. ### Simulating transfer scenarios in test mode In test mode, you can simulate various transfer scenarios by adjusting the transfer amount. This allows you to mimic the typical status progression of a real-world transfer. Note that a transfer's progression will stop once it reaches a final status:blocked,failed,processed, orreturned. | Amount | Scenario | Webhook sequence | |---------|-----------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------| |11.00| Transfer initiated, pending review by Mollie |business-account-transfer.requested→business-account-transfer.initiated→business-account-transfer.pending-review| |12.00| Transfer initiated, blocked by Mollie |business-account-transfer.requested→business-account-transfer.initiated→business-account-transfer.pending-review→business-account-transfer.blocked| |13.00| Transfer initiated, failed on scheme submission |business-account-transfer.requested→business-account-transfer.initiated→business-account-transfer.failed| |14.00| Transfer processed, then returned by receiving bank |business-account-transfer.requested→business-account-transfer.initiated→business-account-transfer.processed→business-account-transfer.returned| | Other | Default: transfer is processed |business-account-transfer.requested→business-account-transfer.initiated→business-account-transfer.processed|
Parameters
connection(MollieAPI.Connection): Connection to serverx_client_signature(String.t): A cryptographic signature of the request payload, used to verify the authenticity of the transfer request.x_client_signed_at(String.t): The timestamp (in ISO 8601 format) indicating when the client signed the request. Used in conjunction withX-Client-Signaturefor request verification.idempotency_key(String.t): A unique value used to identify this request and prevent duplicate transfers. UUIDv4 is recommended to guarantee uniqueness across multiple processes or servers. If two requests are received with the same idempotency key, the second request will be discarded. View the public documentation to learn more.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(TransferRequest):
Returns
{:ok, MollieAPI.Model.TransferResponse.t}on success{:error, Tesla.Env.t}on failure
@spec get_transfer(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.TransferResponse.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Get transfer
🚧 Beta feature > > This feature is currently in beta testing, and the final specification may still change. Retrieve a single transfer object by its transfer ID. This allows you to check the current status and details of a previously created transfer.
Parameters
connection(MollieAPI.Connection): Connection to serverbusiness_accounts_transfer_id(String.t): Provide the ID of the related transfer.opts(keyword): Optional parameters:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.TransferResponse.t}on success{:error, Tesla.Env.t}on failure