MollieAPI.Api.UnmatchedCreditTransfersAPI (mollie_api v0.1.0-20260428)

API calls for all endpoints tagged UnmatchedCreditTransfersAPI.

Summary

Functions

get_unmatched_credit_transfer(connection, unmatched_credit_transfer_id, opts \\ [])

@spec get_unmatched_credit_transfer(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:ok, MollieAPI.Model.EntityUnmatchedCreditTransfer.t()}
  | {:error, Tesla.Env.t()}

Get unmatched credit transfer

🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Retrieves a single unmatched credit transfer by its identifier.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • unmatched_credit_transfer_id (String.t): Provide the ID of the related unmatched credit transfer.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.EntityUnmatchedCreditTransfer.t} on success
  • {:error, Tesla.Env.t} on failure

list_unmatched_credit_transfers(connection, opts \\ [])

@spec list_unmatched_credit_transfers(
  Tesla.Env.client(),
  keyword()
) ::
  {:ok, MollieAPI.Model.ListUnmatchedCreditTransfers200Response.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

List unmatched credit transfers

🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Retrieves a list of unmatched credit transfers for the profile. The results are paginated.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • opts (keyword): Optional parameters
    • :from (String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.
    • :limit (integer()): The maximum number of items to return. Defaults to 50 items.
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.ListUnmatchedCreditTransfers200Response.t} on success
  • {:error, Tesla.Env.t} on failure

match_unmatched_credit_transfer(connection, unmatched_credit_transfer_id, opts \\ [])

@spec match_unmatched_credit_transfer(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.UnmatchedCreditTransferActionResponse.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Match unmatched credit transfer

🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Matches an unmatched credit transfer to one or more payments, settling the funds accordingly.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • unmatched_credit_transfer_id (String.t): Provide the ID of the related unmatched credit transfer.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
    • :body (UnmatchedCreditTransferMatchRequest):

Returns

  • {:ok, MollieAPI.Model.UnmatchedCreditTransferActionResponse.t} on success
  • {:error, Tesla.Env.t} on failure

return_unmatched_credit_transfer(connection, unmatched_credit_transfer_id, opts \\ [])

@spec return_unmatched_credit_transfer(Tesla.Env.client(), String.t(), keyword()) ::
  {:ok, MollieAPI.Model.UnmatchedCreditTransferActionResponse.t()}
  | {:ok, MollieAPI.Model.ErrorResponse.t()}
  | {:error, Tesla.Env.t()}

Return unmatched credit transfer

🚧 Beta feature > > This feature is currently in private beta, and the final specification may still change. Returns an unmatched credit transfer, sending the funds back to the original sender.

Parameters

  • connection (MollieAPI.Connection): Connection to server
  • unmatched_credit_transfer_id (String.t): Provide the ID of the related unmatched credit transfer.
  • opts (keyword): Optional parameters
    • :"idempotency-key" (String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.

Returns

  • {:ok, MollieAPI.Model.UnmatchedCreditTransferActionResponse.t} on success
  • {:error, Tesla.Env.t} on failure