MollieAPI.Api.WalletsAPI (mollie_api v0.1.0-20260217)
View SourceAPI calls for all endpoints tagged WalletsAPI.
Summary
Functions
Request Apple Pay payment session
When integrating Apple Pay in your own checkout on the web, you need to provide merchant validation. This is normally done using Apple's Requesting an Apple Pay Session. The merchant validation proves to Apple that a validated merchant is calling the Apple Pay Javascript APIs. To integrate Apple Pay via Mollie, you will have to call the Mollie API instead of Apple's API. The response of this API call can then be passed as-is to the completion method, completeMerchantValidation. Before requesting an Apple Pay Payment Session, you must place the domain validation file on your server at: https://[domain]/.well-known/apple-developer-merchantid-domain-association. Without this file, it will not be possible to use Apple Pay on your domain. Each new transaction requires a new payment session object. Merchant session objects are not reusable, and they expire after five minutes. Payment sessions cannot be requested directly from the browser. The request must be sent from your server. For the full documentation, see the official Apple Pay JS API documentation.
Functions
@spec request_apple_pay_payment_session( Tesla.Env.client(), keyword() ) :: {:ok, %{optional(String.t()) => any()}} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Request Apple Pay payment session
When integrating Apple Pay in your own checkout on the web, you need to provide merchant validation. This is normally done using Apple's Requesting an Apple Pay Session. The merchant validation proves to Apple that a validated merchant is calling the Apple Pay Javascript APIs. To integrate Apple Pay via Mollie, you will have to call the Mollie API instead of Apple's API. The response of this API call can then be passed as-is to the completion method, completeMerchantValidation. Before requesting an Apple Pay Payment Session, you must place the domain validation file on your server at: https://[domain]/.well-known/apple-developer-merchantid-domain-association. Without this file, it will not be possible to use Apple Pay on your domain. Each new transaction requires a new payment session object. Merchant session objects are not reusable, and they expire after five minutes. Payment sessions cannot be requested directly from the browser. The request must be sent from your server. For the full documentation, see the official Apple Pay JS API documentation.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(RequestApplePayPaymentSessionRequest):
Returns
{:ok, %{}}on success{:error, Tesla.Env.t}on failure