MollieAPI.Model.AfterBalance (mollie_api v0.1.0-20260428)
View SourceThe balance of the business account after this transaction was processed.
Summary
Types
@type t() :: %MollieAPI.Model.AfterBalance{total: MollieAPI.Model.Amount.t()}
The balance of the business account after this transaction was processed.
@type t() :: %MollieAPI.Model.AfterBalance{total: MollieAPI.Model.Amount.t()}