MollieAPI.Model.CapabilityRequirementStatus (mollie_api v0.1.0-20260303)
View SourceThe status of the requirement depends on its due date. If no due date is given, the status will be requested.
The status of the requirement depends on its due date. If no due date is given, the status will be requested.