MollieAPI.Model.CreatePaymentLinkRequestApplicationFee (mollie_api v0.1.0-20260303)

With Mollie Connect you can charge fees on payment links that your app is processing on behalf of other Mollie merchants. If you use OAuth to create payment links on a connected merchant's account, you can charge a fee using this applicationFee parameter. If a payment on the payment link succeeds, the fee will be deducted from the merchant's balance and sent to your own account balance.

Summary

Types

t()

@type t() :: %MollieAPI.Model.CreatePaymentLinkRequestApplicationFee{
  amount: MollieAPI.Model.Amount.t(),
  description: String.t()
}

Functions

decode(value)