MollieAPI.Model.CreditDebitIndicator (mollie_api v0.1.0-20260428)
View SourceIndicates whether the entry is a credit or debit from the perspective of the account holder.
Indicates whether the entry is a credit or debit from the perspective of the account holder.