MollieAPI.Model.DraftTransferStatusReasonCodeResponse (mollie_api v0.1.0-20260819)
View SourceA machine-readable code that indicates the reason for the draft transfer's current status.
A machine-readable code that indicates the reason for the draft transfer's current status.