MollieAPI.Model.EntityBalanceTransactionDeductionDetails (mollie_api v0.1.0-20260303)

A detailed breakdown of the deductions withheld from the movement. Each field represents a specific type of deduction applied to the transaction. Only the applicable fields will be present.

Summary

Types

t()

@type t() :: %MollieAPI.Model.EntityBalanceTransactionDeductionDetails{
  commissions: MollieAPI.Model.AmountNullable.t() | nil,
  fees: MollieAPI.Model.AmountNullable.t() | nil,
  repayments: MollieAPI.Model.AmountNullable.t() | nil,
  reservations: MollieAPI.Model.AmountNullable.t() | nil
}

Functions

decode(value)