MollieAPI.Model.EntityPaymentApplicationFee (mollie_api v0.1.0-20260303)
View SourceWith Mollie Connect you can charge fees on payments that your app is processing on behalf of other Mollie merchants. If you use OAuth to create payments on a connected merchant's account, you can charge a fee using this applicationFee parameter. If the payment succeeds, the fee will be deducted from the merchant's balance and sent to your own account balance. If instead you want to split a payment on your own account between yourself and a connected merchant, refer to the routing parameter.
Summary
Types
@type t() :: %MollieAPI.Model.EntityPaymentApplicationFee{ amount: MollieAPI.Model.Amount.t() | nil, description: String.t() | nil }