MollieAPI.Model.EntityPaymentBillingAddress (mollie_api v0.1.0-20260303)

The customer's billing address details. We advise to provide these details to improve fraud protection and conversion. Should include email or a valid postal address consisting of streetAndNumber, postalCode, city and country. Required for payment method alma, in3, klarna, billie and riverty.

Summary

Types

t()

@type t() :: %MollieAPI.Model.EntityPaymentBillingAddress{
  city: any() | nil,
  country: any() | nil,
  email: any() | nil,
  familyName: any() | nil,
  givenName: any() | nil,
  organizationName: any() | nil,
  phone: any() | nil,
  postalCode: any() | nil,
  region: any() | nil,
  streetAdditional: any() | nil,
  streetAndNumber: any() | nil,
  title: any() | nil
}

Functions

decode(value)