MollieAPI.Model.EntityPaymentDetailsQrCode (mollie_api v0.1.0-20260303)
View SourceOptional include. If a QR code was requested during payment creation for a QR-compatible payment method, the QR code details will be available in this object. The QR code can be scanned by the customer to complete the payment on their mobile device. For example, Bancontact QR payments can be completed by the customer using the Bancontact app.