MollieAPI.Model.EntityProfileReview (mollie_api v0.1.0-20260303)
View SourcePresent if changes have been made that have not yet been approved by Mollie. Changes to test profiles are approved automatically, unless a switch to a live profile has been requested. The review object will therefore usually be null in test mode.
Summary
Types
@type t() :: %MollieAPI.Model.EntityProfileReview{ status: MollieAPI.Model.ProfileReviewStatus.t() | nil }