MollieAPI.Model.EntitySubscriptionApplicationFee (mollie_api v0.1.0-20260206)
View SourceWith Mollie Connect you can charge fees on payments that your app is processing on behalf of other Mollie merchants. Setting an application fee on the subscription will ensure this fee is charged on each individual payment. Refer to the applicationFee parameter on the Get payment endpoint documentation for more information.
Summary
Types
@type t() :: %MollieAPI.Model.EntitySubscriptionApplicationFee{ amount: MollieAPI.Model.Amount.t(), description: String.t() }