MollieAPI.Model.ExtraParameterParametersCompany (mollie_api v0.1.0-20260210)

Billie is a business-to-business (B2B) payment method. It requires extra information to identify the organization that is completing the payment. It is recommended to include these parameters up front for a seamless flow. Otherwise, Billie will ask the customer to complete the missing fields during checkout.

Summary

Types

t()

@type t() :: %MollieAPI.Model.ExtraParameterParametersCompany{
  entityType: String.t() | nil,
  registrationNumber: String.t() | nil,
  vatNumber: String.t() | nil
}

Functions

decode(value)