MollieAPI.Model.ListLinks (mollie_api v0.1.0-20260303)

Links to help navigate through the lists of items. Every URL object will contain an href and a type field.

Summary

Types

t()

@type t() :: %MollieAPI.Model.ListLinks{
  documentation: MollieAPI.Model.Url.t(),
  next: MollieAPI.Model.UrlNullable.t(),
  previous: MollieAPI.Model.UrlNullable.t(),
  self: MollieAPI.Model.Url.t()
}

Functions

decode(value)