MollieAPI.Model.MandateDetailsCardLabelResponse (mollie_api v0.1.0-20260303)
View SourceThe card's label. Available for card mandates, if the card label could be detected.
The card's label. Available for card mandates, if the card label could be detected.