MollieAPI.Model.MandateScopes (mollie_api v0.1.0-20260428)
View SourceAn array defining the eligible use cases for the mandate. For creditcard mandates, this field will always be present and can contain one or both of the following values:
An array defining the eligible use cases for the mandate. For creditcard mandates, this field will always be present and can contain one or both of the following values: