MollieAPI.Model.MandateScopesResponse (mollie_api v0.1.0-20260428)

An array defining the eligible use cases for the mandate. For creditcard mandates, this field will always be present and can contain one or both of the following values:

Summary

Types

t()

@type t() :: %MollieAPI.Model.MandateScopesResponse{}

Functions

decode(value)