MollieAPI.Model.MandateStatus (mollie_api v0.1.0-20260218)

The status of the mandate. A status can be pending for mandates when the first payment is not yet finalized, or when we did not received the IBAN yet from the first payment.

Summary

Types

t()

@type t() :: %MollieAPI.Model.MandateStatus{}

Functions

decode(value)