MollieAPI.Model.OnboardingVatRegulation (mollie_api v0.1.0-20260303)

Mollie applies Dutch VAT for merchants based in The Netherlands, British VAT for merchants based in The United Kingdom, and shifted VAT for merchants in the European Union. The field can be omitted for merchants residing in other countries.

Summary

Types

t()

@type t() :: %MollieAPI.Model.OnboardingVatRegulation{}

Functions

decode(value)