MollieAPI.Model.PaymentDetailsSellerProtectionResponse (mollie_api v0.1.0-20260303)

Indicates to what extent the payment is eligible for PayPal's Seller Protection. Only available for PayPal payments, and if the information is made available by PayPal.

Summary

Types

t()

@type t() :: %MollieAPI.Model.PaymentDetailsSellerProtectionResponse{}

Functions

decode(value)