MollieAPI.Model.PaymentLineTypeResponse (mollie_api v0.1.0-20260303)
View SourceThe type of product purchased. For example, a physical or a digital product. The tip payment line type is not available when creating a payment.
The type of product purchased. For example, a physical or a digital product. The tip payment line type is not available when creating a payment.