MollieAPI.Model.PaymentListRoutes200ResponseLinks (mollie_api v0.1.0-20260303)

Links to help navigate through the lists of items. Every URL object will contain an href and a type field.

Summary

Types

t()

@type t() :: %MollieAPI.Model.PaymentListRoutes200ResponseLinks{
  documentation: MollieAPI.Model.Url.t() | nil,
  self: MollieAPI.Model.Url.t() | nil
}

Functions

decode(value)