MollieAPI.Model.SalesInvoiceEInvoiceStatus (mollie_api v0.1.0-20260622)
View SourceThe e-invoice submission status for the invoice, if it was configured to be an e-invoice.
The e-invoice submission status for the invoice, if it was configured to be an e-invoice.