MollieAPI.Model.SalesInvoiceRecipientTypeResponse (mollie_api v0.1.0-20260303)
View SourceThe type of recipient, either consumer or business. This will determine what further fields are required on the recipient object.
The type of recipient, either consumer or business. This will determine what further fields are required on the recipient object.