MollieAPI.Model.SalesInvoiceVatMode (mollie_api v0.1.0-20260303)

The VAT mode to use for VAT calculation. exclusive mode means we will apply the relevant VAT on top of the price. inclusive means the prices you are providing to us already contain the VAT you want to apply.

Summary

Types

t()

@type t() :: %MollieAPI.Model.SalesInvoiceVatMode{}

Functions

decode(value)