MollieAPI.Model.SalesInvoiceVatScheme (mollie_api v0.1.0-20260303)
View SourceThe VAT scheme to create the invoice for. You must be enrolled with One Stop Shop enabled to use it.
The VAT scheme to create the invoice for. You must be enrolled with One Stop Shop enabled to use it.