MollieAPI.Model.SettlementConvenienceLinks (mollie_api v0.1.0-20260819)
View SourceAn object with several relevant URLs. Every URL object will contain an href and a type field. This endpoint always points to your organization's current open or next settlement rather than one specific settlement, so it doesn't return links to that settlement's payments, captures, refunds, chargebacks, or invoice.
Summary
Types
@type t() :: %MollieAPI.Model.SettlementConvenienceLinks{ documentation: MollieAPI.Model.Url.t() | nil, self: MollieAPI.Model.Url.t() }