MollieAPI.Model.SettlementMethod (mollie_api v0.1.0-20260819)

The method the cost or revenue subtotal applies to. This is usually a payment method, but can also represent a correction or transaction type that is not tied to a specific payment method.

Summary

Types

t()

@type t() :: %MollieAPI.Model.SettlementMethod{}

Functions

decode(value)