MollieAPI.Model.SettlementRefundStatus (mollie_api v0.1.0-20260904)
View SourceThe refund's status. Settlement refunds are normally refunded, but can be failed if the refund could not be processed.
The refund's status. Settlement refunds are normally refunded, but can be failed if the refund could not be processed.