MollieAPI.Model.StatusReason (mollie_api v0.1.0-20260622)

This object offers details about the status of a payment. Currently it is only available for point-of-sale payments. You can find more information about the possible values of this object on this page.**

Summary

Types

t()

@type t() :: %MollieAPI.Model.StatusReason{
  code: MollieAPI.Model.StatusReasonCode.t(),
  message: String.t()
}

Functions

decode(value)