MollieAPI.Model.TransferSchemeTypeResponse (mollie_api v0.1.0-20260428)
View SourceThe transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer.
The transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer.