MollieAPI.Model.UrlNullable (mollie_api v0.1.0-20260303)
View SourceIn v2 endpoints, URLs are commonly represented as objects with an href and type field.
In v2 endpoints, URLs are commonly represented as objects with an href and type field.