MollieAPI.Model.VerificationOfPayeeRequest (mollie_api v0.1.0-20260428)

The request body for performing a Verification of Payee (VoP) check. VoP allows you to verify the account holder name against the records held by the receiving bank before initiating a transfer.

Summary

Types

t()

@type t() :: %MollieAPI.Model.VerificationOfPayeeRequest{
  creditorBankAccount: MollieAPI.Model.CreditorBankAccount.t(),
  testmode: boolean() | nil
}

Functions

decode(value)