MollieAPI.Model.WebhookEventTypesResponse (mollie_api v0.1.0-20260303)

The list of events to enable for this webhook. You may specify '*' to add all events, except those that require explicit selection.

Summary

Types

t()

@type t() :: %MollieAPI.Model.WebhookEventTypesResponse{}

Functions

decode(value)