MollieAPI.Api.AccountsAPI (mollie_api v0.1.0-20260428)
View SourceAPI calls for all endpoints tagged AccountsAPI.
Summary
Functions
Get business account Retrieve a single business account object by its account ID. This allows you to check the current status, balance, and account details.
Get transaction Retrieve a single transaction object by its transaction ID. This allows you to check the details, amount, counterparty, and balance impact of a specific transaction.
List transactions Retrieve all transactions for a specific business account. The results are paginated.
List business accounts Retrieve all business accounts for the authenticated organization. The results are paginated.
Functions
@spec get_business_account(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.BusinessAccountResponse.t()} | {:error, Tesla.Env.t()}
Get business account Retrieve a single business account object by its account ID. This allows you to check the current status, balance, and account details.
Parameters
connection(MollieAPI.Connection): Connection to serverbusiness_account_id(String.t): Provide the ID of the related business account.opts(keyword): Optional parameters:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.BusinessAccountResponse.t}on success{:error, Tesla.Env.t}on failure
@spec get_business_account_transaction( Tesla.Env.client(), String.t(), String.t(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.TransactionResponse.t()} | {:error, Tesla.Env.t()}
Get transaction Retrieve a single transaction object by its transaction ID. This allows you to check the details, amount, counterparty, and balance impact of a specific transaction.
Parameters
connection(MollieAPI.Connection): Connection to serverbusiness_account_id(String.t): Provide the ID of the related business account.transaction_id(String.t): Provide the ID of the related transaction.opts(keyword): Optional parameters:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.TransactionResponse.t}on success{:error, Tesla.Env.t}on failure
@spec list_business_account_transactions(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListBusinessAccountTransactions200Response.t()} | {:error, Tesla.Env.t()}
List transactions Retrieve all transactions for a specific business account. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serverbusiness_account_id(String.t): Provide the ID of the related business account.opts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListBusinessAccountTransactions200Response.t}on success{:error, Tesla.Env.t}on failure
@spec list_business_accounts( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListBusinessAccounts200Response.t()} | {:error, Tesla.Env.t()}
List business accounts Retrieve all business accounts for the authenticated organization. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListBusinessAccounts200Response.t}on success{:error, Tesla.Env.t}on failure