MollieAPI.Api.CapabilitiesAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged CapabilitiesAPI.
Summary
Functions
List capabilities
Functions
@spec list_capabilities( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ListCapabilities200Response.t()} | {:error, Tesla.Env.t()}
List capabilities
🚧 Beta feature > > This feature is currently in beta testing, and the final specification may still change. Retrieve a list of capabilities for an organization. This API provides detailed insights into the specific requirements and status of each client's onboarding journey. Capabilities are at the organization level, indicating if the organization can perform a given capability. For payments, regardless them being at the profile level, the capability is listed at the organization level. This means that if at least one of the clients's profiles can receive payments, the payments capability is enabled, communicating that the organization can indeed receive payments.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListCapabilities200Response.t}on success{:error, Tesla.Env.t}on failure