MollieAPI.Api.RefundsAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged RefundsAPI.
Summary
Functions
Cancel payment refund
Refunds will be executed with a delay of two hours. Until that time, refunds may be canceled manually via the Mollie Dashboard, or by using this endpoint. A refund can only be canceled while its status field is either queued or pending. See the Get refund endpoint for more information.
Create payment refund Creates a refund for a specific payment. The refunded amount is credited to your customer usually either via a bank transfer or by refunding the amount to your customer's credit card.
Get payment refund Retrieve a single payment refund by its ID and the ID of its parent payment.
List all refunds Retrieve a list of all of your refunds. The results are paginated.
List payment refunds Retrieve a list of all refunds created for a specific payment. The results are paginated.
Functions
@spec cancel_refund(Tesla.Env.client(), String.t(), String.t(), keyword()) :: {:ok, nil} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Cancel payment refund
Refunds will be executed with a delay of two hours. Until that time, refunds may be canceled manually via the Mollie Dashboard, or by using this endpoint. A refund can only be canceled while its status field is either queued or pending. See the Get refund endpoint for more information.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.refund_id(String.t): Provide the ID of the related refund.opts(keyword): Optional parameters:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, nil}on success{:error, Tesla.Env.t}on failure
@spec create_refund(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.EntityRefundResponse.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Create payment refund Creates a refund for a specific payment. The refunded amount is credited to your customer usually either via a bank transfer or by refunding the amount to your customer's credit card.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(RefundRequest):
Returns
{:ok, MollieAPI.Model.EntityRefundResponse.t}on success{:error, Tesla.Env.t}on failure
@spec get_refund(Tesla.Env.client(), String.t(), String.t(), keyword()) :: {:ok, MollieAPI.Model.EntityRefundResponse.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Get payment refund Retrieve a single payment refund by its ID and the ID of its parent payment.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.refund_id(String.t): Provide the ID of the related refund.opts(keyword): Optional parameters:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityRefundResponse.t}on success{:error, Tesla.Env.t}on failure
@spec list_all_refunds( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListSettlementRefunds200Response.t()} | {:error, Tesla.Env.t()}
List all refunds Retrieve a list of all of your refunds. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:profileId(String.t): The identifier referring to the profile you wish to retrieve the resources for. Most API credentials are linked to a single profile. In these cases theprofileIdmust not be sent. For organization-level credentials such as OAuth access tokens however, theprofileIdparameter is required.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListSettlementRefunds200Response.t}on success{:error, Tesla.Env.t}on failure
@spec list_refunds(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListSettlementRefunds200Response.t()} | {:error, Tesla.Env.t()}
List payment refunds Retrieve a list of all refunds created for a specific payment. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serverpayment_id(String.t): Provide the ID of the related payment.opts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:embed(String.t): This endpoint allows embedding related API items by appending the following values via theembedquery string parameter.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListSettlementRefunds200Response.t}on success{:error, Tesla.Env.t}on failure