MollieAPI.Api.TerminalsAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged TerminalsAPI.
Summary
Functions
Get terminal Retrieve a single terminal by its ID.
List terminals Retrieve a list of all physical point-of-sale devices. The results are paginated.
Functions
@spec get_terminal(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.EntityTerminal.t()} | {:error, Tesla.Env.t()}
Get terminal Retrieve a single terminal by its ID.
Parameters
connection(MollieAPI.Connection): Connection to serverterminal_id(String.t): Provide the ID of the related terminal.opts(keyword): Optional parameters:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityTerminal.t}on success{:error, Tesla.Env.t}on failure
@spec list_terminals( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListTerminals200Response.t()} | {:error, Tesla.Env.t()}
List terminals Retrieve a list of all physical point-of-sale devices. The results are paginated.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:testmode(boolean()): Most API credentials are specifically created for either live mode or test mode. In those cases thetestmodequery parameter must not be sent. For organization-level credentials such as OAuth access tokens, you can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListTerminals200Response.t}on success{:error, Tesla.Env.t}on failure