MollieAPI.Api.WebhookEventsAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged WebhookEventsAPI.
Summary
Functions
Get a Webhook Event Retrieve a single webhook event object by its event ID.
Functions
@spec get_webhook_event(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.EntityWebhookEvent.t()} | {:error, Tesla.Env.t()}
Get a Webhook Event Retrieve a single webhook event object by its event ID.
Parameters
connection(MollieAPI.Connection): Connection to serverwebhook_event_id(String.t): Provide the ID of the related webhook event.opts(keyword): Optional parameters:testmode(boolean()): You can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityWebhookEvent.t}on success{:error, Tesla.Env.t}on failure