MollieAPI.Api.WebhooksAPI (mollie_api v0.1.0-20260303)
View SourceAPI calls for all endpoints tagged WebhooksAPI.
Summary
Functions
Create a webhook A webhook must have a name, an url and a list of event types. You can also create webhooks in the webhooks settings section of the Dashboard.
Delete a webhook Delete a single webhook object by its webhook ID.
Get a webhook Retrieve a single webhook object by its ID.
List all webhooks Returns a paginated list of your webhooks. If no webhook endpoints are available, the resulting array will be empty. This request should never throw an error.
Test a webhook Sends a test event to the webhook to verify the endpoint is working as expected.
Update a webhook Updates the webhook. You may edit the name, url and the list of subscribed event types.
Functions
@spec create_webhook( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.CreateWebhook.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Create a webhook A webhook must have a name, an url and a list of event types. You can also create webhooks in the webhooks settings section of the Dashboard.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(CreateWebhookRequest):
Returns
{:ok, MollieAPI.Model.CreateWebhook.t}on success{:error, Tesla.Env.t}on failure
@spec delete_webhook(Tesla.Env.client(), String.t(), keyword()) :: {:ok, nil} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Delete a webhook Delete a single webhook object by its webhook ID.
Parameters
connection(MollieAPI.Connection): Connection to serverwebhook_id(String.t): Provide the ID of the related webhook.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(DeleteWebhookRequest):
Returns
{:ok, nil}on success{:error, Tesla.Env.t}on failure
@spec get_webhook(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.EntityWebhook.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Get a webhook Retrieve a single webhook object by its ID.
Parameters
connection(MollieAPI.Connection): Connection to serverwebhook_id(String.t): Provide the ID of the related webhook.opts(keyword): Optional parameters:testmode(boolean()): You can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.EntityWebhook.t}on success{:error, Tesla.Env.t}on failure
@spec list_webhooks( Tesla.Env.client(), keyword() ) :: {:ok, MollieAPI.Model.ErrorResponse.t()} | {:ok, MollieAPI.Model.ListWebhooks200Response.t()} | {:error, Tesla.Env.t()}
List all webhooks Returns a paginated list of your webhooks. If no webhook endpoints are available, the resulting array will be empty. This request should never throw an error.
Parameters
connection(MollieAPI.Connection): Connection to serveropts(keyword): Optional parameters:from(String.t): Provide an ID to start the result set from the item with the given ID and onwards. This allows you to paginate the result set.:limit(integer()): The maximum number of items to return. Defaults to 50 items.:sort(Sorting): Used for setting the direction of the result set. Defaults to descending order, meaning the results are ordered from newest to oldest.:eventTypes(WebhookEventTypes): Used to filter out only the webhooks that are subscribed to certain types of events.:testmode(boolean()): You can enable test mode by setting thetestmodequery parameter totrue. Test entities cannot be retrieved when the endpoint is set to live mode, and vice versa.:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.
Returns
{:ok, MollieAPI.Model.ListWebhooks200Response.t}on success{:error, Tesla.Env.t}on failure
@spec test_webhook(Tesla.Env.client(), String.t(), keyword()) :: {:ok, nil} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Test a webhook Sends a test event to the webhook to verify the endpoint is working as expected.
Parameters
connection(MollieAPI.Connection): Connection to serverwebhook_id(String.t): Provide the ID of the related webhook.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(DeleteWebhookRequest):
Returns
{:ok, nil}on success{:error, Tesla.Env.t}on failure
@spec update_webhook(Tesla.Env.client(), String.t(), keyword()) :: {:ok, MollieAPI.Model.EntityWebhook.t()} | {:ok, MollieAPI.Model.ErrorResponse.t()} | {:error, Tesla.Env.t()}
Update a webhook Updates the webhook. You may edit the name, url and the list of subscribed event types.
Parameters
connection(MollieAPI.Connection): Connection to serverwebhook_id(String.t): Provide the ID of the related webhook.opts(keyword): Optional parameters:"idempotency-key"(String.t): A unique key to ensure idempotent requests. This key should be a UUID v4 string.:body(UpdateWebhookRequest):
Returns
{:ok, MollieAPI.Model.EntityWebhook.t}on success{:error, Tesla.Env.t}on failure