MollieAPI.Model.CaptureModeResponse (mollie_api v0.1.0-20260303)
View SourceIndicate if the funds should be captured immediately or if you want to place a hold and capture at a later time. This field needs to be set to manual for method riverty.