MollieAPI.Model.EntityBalanceReportTotals (mollie_api v0.1.0-20260303)
View SourceTotals are grouped according to the chosen grouping rule. The example response should give a good idea of what a typical grouping looks like. If grouping status-balances is chosen, the main grouping is as follows: pendingBalance containing an open, pending, movedToAvailable, and close sub-group availableBalance containing an open, movedFromPending, immediatelyAvailable, and close sub-group If grouping transaction-categories is chosen, the main grouping is as follows: open and close groups, each containing a pending and available sub-group Transaction type groups such as payments, refunds, chargebacks, capital, transfers, fee-prepayments, corrections, topups each containing a pending, movedToAvailable, and immediatelyAvailable sub-group Each sub-group typically has: An amount object containing the group's total amount A count integer if relevant (for example, counting the number of refunds) * A subtotals array containing more sub-group objects if applicable
Summary
Types
@type t() :: %MollieAPI.Model.EntityBalanceReportTotals{ availableBalance: MollieAPI.Model.EntityBalanceReportTotalsAvailableBalance.t() | nil, capital: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, chargebacks: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, close: MollieAPI.Model.EntityBalanceReportTotalsOpen.t() | nil, corrections: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, "fee-prepayments": MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, open: MollieAPI.Model.EntityBalanceReportTotalsOpen.t() | nil, payments: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, pendingBalance: MollieAPI.Model.EntityBalanceReportTotalsPendingBalance.t() | nil, refunds: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, topups: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil, transfers: MollieAPI.Model.EntityBalanceReportTotalsPayments.t() | nil }