MollieAPI.Model.EntityBalanceTransactionContext (mollie_api v0.1.0-20260303)
View SourceDepending on the type of the balance transaction, we will try to give more context about the specific event that triggered it. For example, the context object for a payment transaction will look like {"paymentId": "tr_5B8cwPMGnU6qLbRvo7qEZo", "paymentDescription": "Description"}. Below is a complete list of the context values that each type of transaction will have. Type payment: paymentId, paymentDescription Type capture: paymentId captureId, paymentDescription, captureDescription Type capture-commission: paymentId, paymentDescription, organizationId Type capture-rolling-reserve-release: paymentId, paymentDescription, captureId, captureDescription Type unauthorized-direct-debit: paymentId, paymentDescription Type failed-payment: paymentId, paymentDescription Type refund: paymentId refundId, paymentDescription, refundDescription Type refund-compensation: paymentId refundId, paymentDescription, refundDescription Type returned-refund: paymentId refundId, paymentDescription, refundDescription Type returned-refund-compensation: paymentId refundId, paymentDescription, refundDescription Type chargeback: paymentId chargebackId, paymentDescription, chargebackDescription Type chargeback-reversal: paymentId, chargebackId, paymentDescription, chargebackDescription Type chargeback-compensation: paymentId, chargebackId, paymentDescription, chargebackDescription Type reversed-chargeback-compensation: paymentId, chargebackId, paymentDescription, chargebackDescription Type outgoing-transfer: settlementId transferId Type canceled-outgoing-transfer: settlementId transferId Type returned-transfer: settlementId transferId Type invoice-compensation: invoiceId Type balance-correction: none Type application-fee: paymentId, paymentDescription, payingOwner Type split-payment: paymentId, paymentDescription, paymentOwner Type platform-payment-refund: paymentId refundId, paymentDescription, refundDescription Type returned-platform-payment-refund: paymentId refundId, paymentDescription, refundDescription Type platform-payment-chargeback: paymentId chargebackId, paymentDescription, chargebackDescription Type reversed-platform-payment-chargeback: paymentId chargebackId, paymentDescription, chargebackDescription Type payment-commission: paymentId, paymentDescription, organizationId Type reimbursement-fee: paymentId, paymentDescription Type failed-payment-fee: paymentId, paymentDescription Type payment-fee: paymentId, paymentDescription Type cash-advance-loan: none Type platform-connected-organizations-fee: none Type managed-fee: feeType, <name of the fee>Id Type returned-managed-fee: feeType, <name of the fee>Id Type topup: none Type balance-reserve: none Type balance-reserve-return: none Type movement: none Type post-payment-split-payment: paymentId Type cash-collateral-issuance: none Type cash-collateral-release: none
Summary
Types
@type t() :: %MollieAPI.Model.EntityBalanceTransactionContext{ "application-fee": MollieAPI.Model.EntityBalanceTransactionContextApplicationFee.t() | nil, "canceled-outgoing-transfer": MollieAPI.Model.EntityBalanceTransactionContextOutgoingTransfer.t() | nil, capture: MollieAPI.Model.EntityBalanceTransactionContextCapture.t() | nil, "capture-commision": MollieAPI.Model.EntityBalanceTransactionContextCapture.t() | nil, "capture-rolling-reserve-release": MollieAPI.Model.EntityBalanceTransactionContextCapture.t() | nil, chargeback: MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "chargeback-compensation": MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "chargeback-reversal": MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "failed-payment": MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil, "failed-payment-fee": MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil, "invoice-compensation": MollieAPI.Model.EntityBalanceTransactionContextInvoiceCompensation.t() | nil, "managed-fee": MollieAPI.Model.EntityBalanceTransactionContextManagedFee.t() | nil, "outgoing-transfer": MollieAPI.Model.EntityBalanceTransactionContextOutgoingTransfer.t() | nil, payment: MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil, "payment-commission": MollieAPI.Model.EntityBalanceTransactionContextPaymentCommission.t() | nil, "payment-fee": MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil, "platform-payment-chargeback": MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "platform-payment-refund": MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "post-payment-split-payment": MollieAPI.Model.EntityBalanceTransactionContextPostPaymentSplitPayment.t() | nil, refund: MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "refund-compensation": MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "reimbursement-fee": MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil, "returned-managed-fee": MollieAPI.Model.EntityBalanceTransactionContextManagedFee.t() | nil, "returned-platform-payment-refund": MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "returned-refund": MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "returned-refund-compensation": MollieAPI.Model.EntityBalanceTransactionContextRefund.t() | nil, "returned-transfer": MollieAPI.Model.EntityBalanceTransactionContextReturnedTransfer.t() | nil, "reversed-chargeback-compensation": MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "reversed-platform-payment-chargeback": MollieAPI.Model.EntityBalanceTransactionContextChargeback.t() | nil, "split-payment": MollieAPI.Model.EntityBalanceTransactionContextSplitPayment.t() | nil, "unauthorized-direct-debit": MollieAPI.Model.EntityBalanceTransactionContextPayment.t() | nil }