MollieAPI.Model.MandateStatus (mollie_api v0.1.0-20260303)
View SourceThe status of the mandate. A status can be pending for mandates when the first payment is not yet finalized, or when we did not received the IBAN yet from the first payment.
The status of the mandate. A status can be pending for mandates when the first payment is not yet finalized, or when we did not received the IBAN yet from the first payment.