MollieAPI.Model.StatusReason2 (mollie_api v0.1.0-20260428)
View SourceA human-readable reason explaining the current status of the transfer. Only populated when the transfer has reached a terminal status of failed, rejected, or blocked. This field is null for transfers that have not reached one of these statuses.
Summary
Types
@type t() :: %MollieAPI.Model.StatusReason2{ code: MollieAPI.Model.StatusReasonCodeResponse.t() | nil, message: String.t() | nil }