MollieAPI.Model.SubscriptionStatusResponse (mollie_api v0.1.0-20260303)
View SourceThe subscription's current status is directly related to the status of the underlying customer or mandate that is enabling the subscription.
The subscription's current status is directly related to the status of the underlying customer or mandate that is enabling the subscription.