MollieAPI.Model.WebhookEventTypesResponse (mollie_api v0.1.0-20260303)
View SourceThe list of events to enable for this webhook. You may specify '*' to add all events, except those that require explicit selection.
The list of events to enable for this webhook. You may specify '*' to add all events, except those that require explicit selection.